# This package is deprecated!

This package is deprecated, please use 'tensorbay' instead.

## Install tensorbay package:

```console
pip3 install tensorbay
```

## Start using tensorbay:

```python
from tensorbay import GAS
```

## Reference:

-   Github: <https://github.com/Graviti-AI/tensorbay-python-sdk>
-   Pypi: <https://pypi.org/project/tensorbay/>
-   Documentation: <https://tensorbay-python-sdk.graviti.com/en/stable/>
